<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Full-Screen Movie Carousel</title>
    <style>
        body {
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: flex-start;
            align-items: center;
            height: 100vh;
            background-color: #222;
            backdrop-filter: blur(0px); 
            background-repeat: no-repeat;
            background-size: cover; 
            position: relative;
            overflow: hidden; 
        }
        #movie-container {
            opacity: 0; 
            transition: opacity 0.2s ease-in-out; 
        }
        .movie-banner {
            display: flex;
            flex-direction: column;
            justify-content: space-between; 
            align-items: flex-start; 
            color: #fff;
            padding-left: 0; 
            position: relative;
            z-index: 2; 
            height: 100%;
        }

        #movie-poster-container {
            position: relative;
            width: auto;
            max-height: 100%; 
        }

        #movie-poster {
            width: 100%;
            height: 100%; 
            -webkit-mask-image: -webkit-gradient(linear, right top, left top, from(rgba(0,0,0,0)), to(rgba(0,0,0,1))); 
        }

        .overlay {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: linear-gradient(to right, rgba(0, 0, 0, 0), transparent);
            z-index: 1; 
        }

        .movie-info {
            position: fixed;
            top: 4.5vw;
            left: 01%;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size:4.5vw;
        }
        .subtitial-info{
            position: absolute;
            top: 5.9vw;
            right: 16px;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size: 1.5vw;
        }
        
        .ratingbar-location{
            position: absolute;
            top: 9.1vw;
            right: 16px;
            font-size: 1.1vw;
        }

        .movie-info-larger {
            position: absolute;
            top: 2.5vw;
            display: flex;
            top: 8px;
            right: 16px;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            white-space: nowrap;
            font-size:3.3vw;
        }
        .movie-info-twoventryfive {
            position: fixed;
            top: 7.2vw;
            left: 01%;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            white-space: nowrap;
            font-size:3.3vw;
        }
        .movie-info-larger-forty {
            position: fixed;
            top: 15%;
            left: 01%;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size: 2.4vw;
        }
        .movie-info-larger-thertyfive {
            position: fixed;
            top: 15%;
            left: 01%;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size: 2.6vw;
        }
        .movie-info-larger-fortyfive {
            position: fixed;
            top: 15%;
            left: 01%;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size: 1.9vw;
        }

        .movie-info-overview {
            text-align: left;
            position: fixed;
            top: 20.8vw;
            left: 01%;
            right: 25%;
            font-size: 0.1vm;
            color: white;
        }
        .overview-location {
            top: 18.8vw;
            left: 01%;
            position: fixed;
            display: flex;
            align-items: center;
            justify-content: center;
            text-transform: uppercase;
            color: white;
            font-size: 1.4vw;
        }
        #rating-rtx {
            font-size: 1.5vw;
            color: white;
            position: absolute;
            top: 9.6vw;
            right: 16px;
        }
    </style>
</head>
<body>
    <div class="movie-container" id="movie-container">
        <div class="overlay" id="viewport_capture">
            <div class="movie-banner">
                <div id="movie-poster-container">
                    <!-- Placeholder for Movie Poster -->
                </div>
            </div> 
            <h1 id="movie-title" class="movie-info-larger"></h1>
            <p id="msubtitial" class="subtitial-info"></p>
            <div class="ratingbar-location" id="rating-rtx"></div>
            <h1 id="overview-title" class="overview-location"></h1>
            <h3 id="movie-overview" class="movie-info-overview"></h3>
        </div>
    </div>
    <script>
        const apiKey = '6b8e3eaa1a03ebb45642e9531d8a76d2'; // Replace with your TMDb API key
        let currentIndex = 0;
        let currentPage = 1; 
        let totalPageCount = 15;
        let movieIds = []; 
        let nextImage = null; 

        // Function to generate star rating and numerical rating
        function generateRatingStars(rating) {
            let stars = '';
            for (let i = 0; i < Math.round(rating); i++) {
                stars += '⭐';
            }
            return stars + ` (${rating.toFixed(1)})`;
        }

        // Function to fetch popular movie IDs
        async function fetchPopularMovieIds() {
            while (currentPage <= totalPageCount) {
                try {
                    const response = await fetch(`https://api.themoviedb.org/3/discover/movie?api_key=${apiKey}&page=${currentPage}&sort_by=popularity.desc`);
                    const data = await response.json();
                    
                    movieIds = [...movieIds, ...data.results.map(movie => movie.id)];
                    
                    currentPage++;
                } catch (error) {
                    console.error(error);
                    break;
                }
            }
        }

        // Function to preload the next image
        function preloadNextImage() {
            if (movieIds.length === 0) {
                console.error('Failed to fetch movie IDs.');
                return;
            }

            const nextIndex = (currentIndex + 1) % movieIds.length;
            const nextMovieId = movieIds[nextIndex];

            fetch(`https://api.themoviedb.org/3/movie/${nextMovieId}?api_key=${apiKey}`)
                .then((response) => response.json())
                .then((data) => {
                    nextImage = new Image();
                    nextImage.src = `https://image.tmdb.org/t/p/original${data.backdrop_path}`;
                })
                .catch((error) => console.error(error));
        }

        // Function to update movie information
        async function updateMovieInfo() {
            if (movieIds.length === 0) {
                console.error('Failed to fetch movie IDs.');
                return;
            }

            const movieId = movieIds[currentIndex];

            fetch(`https://api.themoviedb.org/3/movie/${movieId}?api_key=${apiKey}`)
                .then((response) => response.json())
                .then((data) => {
                    const movieContainer = document.getElementById('movie-container');

                    movieContainer.style.opacity = 0;

                    setTimeout(() => {
                        preloadNextImage();
                        
                        const moviePoster = document.getElementById('movie-poster');
                        const movieTitle = document.getElementById('movie-title');
                        const mcategory = document.getElementById('msubtitial');
                        const movieOverview = document.getElementById('movie-overview');
                        // Update movie details
                        const posterPath = `https://image.tmdb.org/t/p/original${data.backdrop_path}`;
                        document.body.style.backgroundImage = `url('${posterPath}')`;

                        // Update movie title
                        const releaseDate = data.release_date;
                        const releaseYear = new Date(releaseDate).getFullYear();
                        movieTitle.innerText = data.title + ` (${releaseYear})`;

                        // Update movie sub-title
                        const genresArray = data.genres.map(genre => `🎬 ${genre.name}`).join(' ');
                        const origin_country = data.production_companies.map(production_companies => `${production_companies.origin_country}`).join(' ');
                        const duration = data.runtime;
                        const hours = Math.floor(duration / 60) + 'h';
                        const minutes = duration % 60 + 'm';
                        mcategory.innerText = `📀 ${releaseDate} (${origin_country}) | ${genresArray} | 🕝 ${hours} ${minutes}`;

                        // Update star rating
                        const movieRating = document.getElementById('rating-rtx');
                        movieRating.innerHTML = generateRatingStars(data.vote_average);

                        movieContainer.style.opacity = 1;

                        currentIndex = (currentIndex + 1) % movieIds.length;
                    }, 200);
                })
                .catch((error) => console.error(error));
        }

        // Event listener for left and right arrow keys to navigate the carousel
        document.addEventListener('keydown', (event) => {
            if (event.key === 'ArrowLeft') {
                currentIndex = (currentIndex - 1 + movieIds.length) % movieIds.length;
                updateMovieInfo();
            } else if (event.key === 'ArrowRight') {
                currentIndex = (currentIndex + 1) % movieIds.length;
                updateMovieInfo();
            }
        });

        // Initial function calls and setup
        fetchPopularMovieIds().then(() => {
            preloadNextImage();
            updateMovieInfo(); // Call it initially
            setInterval(updateMovieInfo, 9000); // Automatic slide every 9 seconds
        });
    </script>
</body>
</html>